@@ -38,12 +38,10 @@
 ****************************************************************************/
 
 #include "framecleanupjob_p.h"
-#include <private/renderer_p.h>
 #include <private/nodemanagers_p.h>
 #include <private/entity_p.h>
 #include <private/shaderdata_p.h>
 #include <private/managers_p.h>
-#include <private/texturedatamanager_p.h>
 #include <private/sphere_p.h>
 #include <Qt3DRender/private/job_common_p.h>
 
@@ -56,7 +54,7 @@ FrameCleanupJob::FrameCleanupJob()
     : m_managers(nullptr)
     , m_root(nullptr)
 {
-    SET_JOB_RUN_STAT_TYPE(this, JobTypes::FrameCleanup, 0);
+    SET_JOB_RUN_STAT_TYPE(this, JobTypes::FrameCleanup, 0)
 }
 
 FrameCleanupJob::~FrameCleanupJob()
@@ -70,32 +68,29 @@ void FrameCleanupJob::setRoot(Entity *root)
 
 void FrameCleanupJob::run()
 {
-    // mark each ShaderData clean
-    ShaderData::cleanup(m_managers);
-
     // Debug bounding volume debug
     updateBoundingVolumesDebug(m_root);
 }
 
 void FrameCleanupJob::updateBoundingVolumesDebug(Entity *node)
 {
+    Q_UNUSED(node);
 #if 0
-    BoundingVolumeDebug *debugBV = node->renderComponent<BoundingVolumeDebug>();
-    if (debugBV) {
-        Qt3DRender::Render::Sphere s;
-        if (!debugBV->isRecursive()) {
-            s = *node->worldBoundingVolume();
-        } else {
-            s = *node->worldBoundingVolumeWithChildren();
+    node->traverse([](Entity *node) {
+        BoundingVolumeDebug *debugBV = node->renderComponent<BoundingVolumeDebug>();
+        if (debugBV) {
+            Qt3DRender::Render::Sphere s;
+            if (!debugBV->isRecursive()) {
+                s = *node->worldBoundingVolume();
+            } else {
+                s = *node->worldBoundingVolumeWithChildren();
+            }
+            debugBV->setRadius(s.radius());
+            debugBV->setCenter(s.center());
         }
-        debugBV->setRadius(s.radius());
-        debugBV->setCenter(s.center());
-    }
-#endif
+    });
 
-    const auto children = node->children();
-    for (Entity *c : children)
-        updateBoundingVolumesDebug(c);
+#endif
 }
 
 void FrameCleanupJob::setManagers(NodeManagers *managers)
